﻿
namespace SL4_RIA_Sample.Web
{
    using System;
    using System.Collections.Generic;
    using System.ComponentModel;
    using System.ComponentModel.DataAnnotations;
    using System.Data.Objects.DataClasses;
    using System.Linq;
    using System.ServiceModel.DomainServices.Hosting;
    using System.ServiceModel.DomainServices.Server;


    // The MetadataTypeAttribute identifies CategoryMetadata as the class
    // that carries additional metadata for the Category class.
    [MetadataTypeAttribute(typeof(Category.CategoryMetadata))]
    public partial class Category
    {

        // This class allows you to attach custom attributes to properties
        // of the Category class.
        //
        // For example, the following marks the Xyz property as a
        // required property and specifies the format for valid values:
        //    [Required]
        //    [RegularExpression("[A-Z][A-Za-z0-9]*")]
        //    [StringLength(32)]
        //    public string Xyz { get; set; }
        internal sealed class CategoryMetadata
        {

            // Metadata classes are not meant to be instantiated.
            private CategoryMetadata()
            {
            }

            public int Category_ID { get; set; }

            public string Category_Name { get; set; }

            public string Description { get; set; }

            public byte[] Picture { get; set; }

            public EntityCollection<Product> Products { get; set; }
        }
    }

    // The MetadataTypeAttribute identifies CustomerMetadata as the class
    // that carries additional metadata for the Customer class.
    [MetadataTypeAttribute(typeof(Customer.CustomerMetadata))]
    public partial class Customer
    {

        // This class allows you to attach custom attributes to properties
        // of the Customer class.
        //
        // For example, the following marks the Xyz property as a
        // required property and specifies the format for valid values:
        //    [Required]
        //    [RegularExpression("[A-Z][A-Za-z0-9]*")]
        //    [StringLength(32)]
        //    public string Xyz { get; set; }
        internal sealed class CustomerMetadata
        {

            // Metadata classes are not meant to be instantiated.
            private CustomerMetadata()
            {
            }

            public string Address { get; set; }

            public string City { get; set; }

            public string Company_Name { get; set; }

            public string Contact_Name { get; set; }

            public string Contact_Title { get; set; }

            public string Country { get; set; }

            public string Customer_ID { get; set; }

            public string Fax { get; set; }

            public EntityCollection<Order> Orders { get; set; }

            public string Phone { get; set; }

            public string Postal_Code { get; set; }

            public string Region { get; set; }
        }
    }

    // The MetadataTypeAttribute identifies EmployeeMetadata as the class
    // that carries additional metadata for the Employee class.
    [MetadataTypeAttribute(typeof(Employee.EmployeeMetadata))]
    public partial class Employee
    {

        // This class allows you to attach custom attributes to properties
        // of the Employee class.
        //
        // For example, the following marks the Xyz property as a
        // required property and specifies the format for valid values:
        //    [Required]
        //    [RegularExpression("[A-Z][A-Za-z0-9]*")]
        //    [StringLength(32)]
        //    public string Xyz { get; set; }
        internal sealed class EmployeeMetadata
        {

            // Metadata classes are not meant to be instantiated.
            private EmployeeMetadata()
            {
            }

            public string Address { get; set; }

            public Nullable<DateTime> Birth_Date { get; set; }

            public string City { get; set; }

            public string Country { get; set; }

            public int Employee_ID { get; set; }

            public string Extension { get; set; }

            public string First_Name { get; set; }

            public Nullable<DateTime> Hire_Date { get; set; }

            public string Home_Phone { get; set; }

            public string Last_Name { get; set; }

            public string Notes { get; set; }

            public EntityCollection<Order> Orders { get; set; }

            public byte[] Photo { get; set; }

            public string Postal_Code { get; set; }

            public string Region { get; set; }

            public Nullable<int> Reports_To { get; set; }

            public string Title { get; set; }
        }
    }

    // The MetadataTypeAttribute identifies OrderMetadata as the class
    // that carries additional metadata for the Order class.
    [MetadataTypeAttribute(typeof(Order.OrderMetadata))]
    public partial class Order
    {

        // This class allows you to attach custom attributes to properties
        // of the Order class.
        //
        // For example, the following marks the Xyz property as a
        // required property and specifies the format for valid values:
        //    [Required]
        //    [RegularExpression("[A-Z][A-Za-z0-9]*")]
        //    [StringLength(32)]
        //    public string Xyz { get; set; }
        internal sealed class OrderMetadata
        {

            // Metadata classes are not meant to be instantiated.
            private OrderMetadata()
            {
            }

            public Customer Customer { get; set; }

            public string Customer_ID { get; set; }

            public Employee Employee { get; set; }

            public Nullable<int> Employee_ID { get; set; }

            public Nullable<decimal> Freight { get; set; }

            public Nullable<DateTime> Order_Date { get; set; }

            public EntityCollection<Order_Detail> Order_Details { get; set; }

            public int Order_ID { get; set; }

            public Nullable<DateTime> Required_Date { get; set; }

            public string Ship_Address { get; set; }

            public string Ship_City { get; set; }

            public string Ship_Country { get; set; }

            public string Ship_Name { get; set; }

            public string Ship_Postal_Code { get; set; }

            public string Ship_Region { get; set; }

            public Nullable<int> Ship_Via { get; set; }

            public Nullable<DateTime> Shipped_Date { get; set; }

            public Shipper Shipper { get; set; }
        }
    }

    // The MetadataTypeAttribute identifies Order_DetailMetadata as the class
    // that carries additional metadata for the Order_Detail class.
    [MetadataTypeAttribute(typeof(Order_Detail.Order_DetailMetadata))]
    public partial class Order_Detail
    {

        // This class allows you to attach custom attributes to properties
        // of the Order_Detail class.
        //
        // For example, the following marks the Xyz property as a
        // required property and specifies the format for valid values:
        //    [Required]
        //    [RegularExpression("[A-Z][A-Za-z0-9]*")]
        //    [StringLength(32)]
        //    public string Xyz { get; set; }
        internal sealed class Order_DetailMetadata
        {

            // Metadata classes are not meant to be instantiated.
            private Order_DetailMetadata()
            {
            }

            public float Discount { get; set; }

            public Order Order { get; set; }

            public int Order_ID { get; set; }

            public Product Product { get; set; }

            public int Product_ID { get; set; }

            public short Quantity { get; set; }

            public decimal Unit_Price { get; set; }
        }
    }

    // The MetadataTypeAttribute identifies ProductMetadata as the class
    // that carries additional metadata for the Product class.
    [MetadataTypeAttribute(typeof(Product.ProductMetadata))]
    public partial class Product
    {

        // This class allows you to attach custom attributes to properties
        // of the Product class.
        //
        // For example, the following marks the Xyz property as a
        // required property and specifies the format for valid values:
        //    [Required]
        //    [RegularExpression("[A-Z][A-Za-z0-9]*")]
        //    [StringLength(32)]
        //    public string Xyz { get; set; }
        internal sealed class ProductMetadata
        {

            // Metadata classes are not meant to be instantiated.
            private ProductMetadata()
            {
            }

            public Category Category { get; set; }

            public Nullable<int> Category_ID { get; set; }

            public bool Discontinued { get; set; }

            public string English_Name { get; set; }

            public EntityCollection<Order_Detail> Order_Details { get; set; }

            public int Product_ID { get; set; }

            public string Product_Name { get; set; }

            public string Quantity_Per_Unit { get; set; }

            public Nullable<short> Reorder_Level { get; set; }

            public Supplier Supplier { get; set; }

            public Nullable<int> Supplier_ID { get; set; }

            public Nullable<decimal> Unit_Price { get; set; }

            public Nullable<short> Units_In_Stock { get; set; }

            public Nullable<short> Units_On_Order { get; set; }
        }
    }

    // The MetadataTypeAttribute identifies ShipperMetadata as the class
    // that carries additional metadata for the Shipper class.
    [MetadataTypeAttribute(typeof(Shipper.ShipperMetadata))]
    public partial class Shipper
    {

        // This class allows you to attach custom attributes to properties
        // of the Shipper class.
        //
        // For example, the following marks the Xyz property as a
        // required property and specifies the format for valid values:
        //    [Required]
        //    [RegularExpression("[A-Z][A-Za-z0-9]*")]
        //    [StringLength(32)]
        //    public string Xyz { get; set; }
        internal sealed class ShipperMetadata
        {

            // Metadata classes are not meant to be instantiated.
            private ShipperMetadata()
            {
            }

            public string Company_Name { get; set; }

            public EntityCollection<Order> Orders { get; set; }

            public int Shipper_ID { get; set; }
        }
    }

    // The MetadataTypeAttribute identifies SupplierMetadata as the class
    // that carries additional metadata for the Supplier class.
    [MetadataTypeAttribute(typeof(Supplier.SupplierMetadata))]
    public partial class Supplier
    {

        // This class allows you to attach custom attributes to properties
        // of the Supplier class.
        //
        // For example, the following marks the Xyz property as a
        // required property and specifies the format for valid values:
        //    [Required]
        //    [RegularExpression("[A-Z][A-Za-z0-9]*")]
        //    [StringLength(32)]
        //    public string Xyz { get; set; }
        internal sealed class SupplierMetadata
        {

            // Metadata classes are not meant to be instantiated.
            private SupplierMetadata()
            {
            }

            public string Address { get; set; }

            public string City { get; set; }

            public string Company_Name { get; set; }

            public string Contact_Name { get; set; }

            public string Contact_Title { get; set; }

            public string Country { get; set; }

            public string Fax { get; set; }

            public string Phone { get; set; }

            public string Postal_Code { get; set; }

            public EntityCollection<Product> Products { get; set; }

            public string Region { get; set; }

            public int Supplier_ID { get; set; }
        }
    }
}
